@@ -375,7 +375,7 @@ while ($poller_runs_completed < $poller_runs) {
 
 		$issue_list = '';
 		foreach($issues as $issue) {
-			$issue_list .= (strlen($issue_list) ? ', ' : '') . $issue['rrd_name'] . '(DS[' . $issue['local_data_id'] . '])';
+			$issue_list .= ($issue_list != '' ? ', ' : '') . $issue['rrd_name'] . '(DS[' . $issue['local_data_id'] . '])';
 		}
 
 		if ($count > $issues_limit) {
@@ -688,7 +688,7 @@ function spikekill_poller_bottom () {
 
 /*  display_version - displays version information */
 function display_version() {
-    $version = db_fetch_cell('SELECT cacti FROM version');
+	$version = get_cacti_version();
 	echo "Cacti Main Poller, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
